/*
 *  file:     m395defs.h
 *  revision: 1.0
 *  date:     24/02/00
 *  author:   JG
 * ----------------------------------------------------------------------
 *
 * M395 12-bit DAC M-module with 16x Voltage Outputs
 * ANSI-C library definitions
 *
 * This header file contains the general definitions for m395lib.c
 * and m395demo.c
 *
 * ----------------------------------------------------------------------
 * Copyright 2000 by AcQuisition Technology bv (c)
 * All Rights Reserved
 * Reproduced Under License
 *
 * This source code is the proprietary confidential property of
 * AcQuisition Technology bv, and is provided to the licensee
 * for documentation and educational purposes only.  Reproduction,
 * publication, or any form of distribution to any party other than
 * the licensee is strictly prohibited.
 * ----------------------------------------------------------------------
 * Edition History
 *
 * #    date        Comments                                        by
 * --   --------    ----------------------------------------------  ---
 * 1.0  24-02-00    First release                                   JG
 *
 */
#ifndef __INCm395defsh
#define __INCm395defsh


#include "apis.h"

#define TRUE 1
#define FALSE 0

/*
 * M395 Memory map
 *
 *  Host register definitions (offsets to module's base address)
 *  communication structures definitions (resides in dual ported SRAM)
 */
#define ODR0    0x0000          /* measurement data channel 0 */
#define ODR1    0x0002          /* measurement data channel 1 */
#define ODR2    0x0004          /* measurement data channel 2 */
#define ODR3    0x0006          /* measurement data channel 3 */
#define ODR4    0x0008          /* measurement data channel 4 */
#define ODR5    0x000A          /* measurement data channel 5 */
#define ODR6    0x000C          /* measurement data channel 6 */
#define ODR7    0x000E          /* measurement data channel 7 */
#define ODR8    0x0010          /* measurement data channel 8 */
#define ODR9    0x0012          /* measurement data channel 9 */
#define ODR10   0x0014          /* measurement data channel 10 */
#define ODR11   0x0016          /* measurement data channel 11 */
#define ODR12   0x0018          /* measurement data channel 12 */
#define ODR13   0x001A          /* measurement data channel 13 */
#define ODR14   0x001C          /* measurement data channel 14 */
#define ODR15   0x001E          /* measurement data channel 15 */

#define C_CMD       0x0040      /* command */
#define C_RES       0x0042      /* execution result */
#define C_PRM0      0x0044      /* parameter 0 */
#define C_PRM1      0x0046      /* parameter 1 */
#define C_PRM2      0x0048      /* parameter 2 */
#define C_PRM3      0x004A      /* parameter 3 */
#define C_PRM4      0x004C      /* parameter 4 */
#define C_PRM5      0x004E      /* parameter 5 */
#define C_PRM6      0x0050      /* parameter 6 */
#define C_PRM7      0x0052      /* parameter 7 */
#define C_PRM8      0x0054      /* parameter 8 */
#define C_PRM9      0x0056      /* parameter 9 */
#define C_PRM10     0x0058      /* parameter 10 */
#define C_PRM11     0x005A      /* parameter 11 */
#define C_PRM12     0x005C      /* parameter 12 */
#define C_PRM13     0x005E      /* parameter 13 */
#define C_PRM14     0x0060      /* parameter 14 */
#define C_PRM15     0x0062      /* parameter 15 */

#define GLOBSTAT    0x0064      /* global status */

#define PAGEREG 0x0080          /* dual ported memory page register */
#define CTRLREG 0x0082          /* control register */

#define EEPREG  0x00FE          /* identification EEPROM register */

/*
 * hardware register bit definitions
 */
#define RESET   0x0004  /* local reset bit */
#define RDY     0x0008  /* ready bit, set by module cleared by host */
#define BOOT    0x0100  /* boot bit, boot selection */
#define CMDPAGE 0x0100  /* command structure resides at memory page 0x100 */

/*******************************************************************
 *
 * M395 Command Set
 *
 */
#define DONE        0x0000  /* command completed */
#define SYNC        0x5a5a  /* synchronize firmware, sign of live */
#define VERSION     0x1000  /* returns version information */
#define RANGE       0x0001  /* select output range */
#define UMODE       0x0002  /* select output update mode */
#define LOAD        0x0003  /* load DAC's */
#define UPDATE      0x0004  /* update analog outputs */

/*
 *command parameter definitions
 */

/* SYNC - synchronize firmware, sign of live
 *
 * VERSION - get version information
 *  parm0: module type, should be 395
 *  parm1: firmware version number
 *
 * RANGE - select ouput range
 *  parm0: output range
 *
 * UMODE - select output update mode
 *  parm0: output update mode
 *
 */
#define MODTYPE     395    /* module type */
/* parameters RANGE */
#define V10UNI      0x0000 /* 0..10 V unipolar (default) */
#define V10BI       0x0001 /* +/- 10 V bipolar */
/* parameters UMODE */
#define CONT        0x0000 /* continuos (default) */
#define ON_DEM      0x0001 /* on-demand */
#define	MODE_16BIT	0x0002 /* 16-bit continuous mode */

/*
 * Command Result Codes
 */
#define NOERR       0x0000  /* no error */
#define UNKCMD      0x8001  /* ERROR: unknown command */
#define ADCFAIL     0x8002  /* ERROR: a-to-d converter failure */
#define ILLREQ      0x8003  /* ERROR: illegal request */

/* Errors */
#define INV_VALUE     0x0004  /* ERROR: invalid value */

/*
 *external functions references
 */
/* open path to m395 */
extern int m395_open (APIS_PATH path, APIS_HANDLE *handle);
/* close path to m395 */
extern void m395_close (APIS_HANDLE);
/* booting m395 */
extern int m395_boot (APIS_HANDLE handle);
/* give command to m395 */
extern int m395_cmd (APIS_HANDLE handle, UINT16 command, UINT16 *pArgList,
                int ni, int no);
/* select output range */
extern int m395_select_range (APIS_HANDLE handle, UINT16 outp_range);
/* select update mode */
extern int m395_select_upd_mode(APIS_HANDLE handle, UINT16 upd_mode);
/* set output of one channel */
extern int m395_setchan(APIS_HANDLE handle, UINT16 channel, UINT16 value);
/* set output of all channels */
extern int m395_setallchan(APIS_HANDLE handle, UINT16 value);
/* update channels (use only with on-demand-update mode ) */
extern int m395_updchan(APIS_HANDLE handle);


#endif /* __INCm395defsh */
